{ config, pkgs, lib, ... }:
{

    programs.firefox = {
      enable = true;

      policies = {
        DisablePocket = true;
        DisplayBookmarksToolbar = true;
        DisableFirefoxStudies = true;
        DisableTelemetry = true;
        PasswordManagerEnabled = false;
        FirefoxHome = {
          Search = true;
          Pocket = false;
          Snippets = false;
          TopSites = false;
          Highlights = false;
          SponsoredPocket = false;
          SponsoredTopSites = false;
        };
        EnableTrackingProtection = {
          Value = true;
          Locked = true;
          Cryptomining = true;
          Fingerprinting = true;
        };

        ExtensionSettings = {
          "jid1-MnnxcxisBPnSXQ@jetpack" = {
            install_url = "https://addons.mozilla.org/firefox/downloads/latest/privacy-badger17/latest.xpi";
            installation_mode = "force_installed";
          };
          "firefox@ghostery.com" = {
            install_url = "https://addons.mozilla.org/firefox/downloads/latest/ghostery/latest.xpi";
            installation_mode = "force_installed";
          };
          "uBlock0@raymondhill.net" = {
            install_url = "https://addons.mozilla.org/firefox/downloads/latest/ublock-origin/latest.xpi";
            installation_mode = "force_installed";
          };
          "{446900e4-71c2-419f-a6a7-df9c091e268b}" = {
            install_url = "https://addons.mozilla.org/firefox/downloads/latest/bitwarden-password-manager/latest.xpi";
            installation_mode = "force_installed";
          };
        };
      };

      profiles = {
        Personal = {
          id = 0;

          search = {
            force = true;
            engines = {
              "Nix Packages" = {
                urls = [
                  {
                    template = "https://search.nixos.org/packages";
                    params = [
                      {
                        name = "query";
                        value = "{searchTerms}";
                      }
                    ];
                    icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
                    definedAliases = [ "@np" ];
                  }
                ];
              };
              "Nix Options" = {
                urls = [
                  {
                    template = "https://search.nixos.org/options";
                    params = [
                      {
                        name = "query";
                        value = "{searchTerms}";
                      }
                    ];
                    icon = "${pkgs.nixos-icons}/share/icons/hicolor/scalable/apps/nix-snowflake.svg";
                    definedAliases = [ "@no" ];
                  }
                ];
              };
            };
          };

          bookmarks = [
            {
              name = "Toolbar";
              toolbar = true;
              bookmarks = [
                {
                  name = "Development";
                  bookmarks = [
                    {
                      name = "Web";
                      bookmarks = [
                        {
                          name = "TypeScript docs";
                          url = "https://www.typescriptlang.org/docs/";
                        }
                      ];
                    }
                    {
                      name = "Typst";
                      bookmarks = [
                        {
                          name = "Typst docs";
                          url = "https://typst.app/docs/";
                        }
                      ];
                    }
                    {
                      name = "Nix";
                      bookmarks = [
                        {
                          name = "Nix(OS) manual (stable)";
                          url = "https://nixos.org/manual/nixos/stable/";
                        }
                        {
                          name = "Home manager options";
                          url = "https://nix-community.github.io/home-manager/options.xhtml";
                        }
                        {
                          name = "Noogle";
                          url = "https://noogle.dev/";
                        }
                        {
                          name = "Nixpkgs";
                          url = "https://github.com/nixos/nixpkgs";
                        }
                      ];
                    }
                    {
                      name = "GitHub";
                      url = "https://github.com/";
                    }
                  ];
                }
                {
                  name = "Radio";
                  bookmarks = [
                    {
                      name = "Meshtastic client";
                      url = "https://client.meshtastic.org/";
                    }
                    {
                      name = "Meshmap";
                      url = "https://meshmap.net";
                    }
                  ];
                }
              ];
            }
            {
              name = "Entertainment";
              bookmarks = [
                {
                  name = "YouTube";
                  url = "https://youtube.com/";
                }
              ];
            }
          ];
        };
      };
    };

    home = {
      sessionVariables.BROWSER = "firefox";
      #persistence."/persist/home/wieerwill" = {
      #  directories = [
      #    ".mozilla/firefox"
      #  ];
      #};
    };

}
