{ config, pkgs, lib, ... }:

let
# Define variables for your workspaces and displays
  display1 = "card1-eDP-1";
  touchDisplay = "10248:4117:FTS3528:00_2808:1015"; #steamdeck
  workspace1 = "1:Web";
  workspace2 = "2:App";
  workspace3 = "3:Chat";
  workspace4 = "4:Read";
  workspace5 = "5:Code";
  workspace6 = "6:Password";
  workspace7 = "7:Shell";
  workspace8 = "8:Media";
in
{

  # Enable Sway window manager
  wayland.windowManager.sway = {
    enable = true;
    wrapperFeatures.gtk = true;
    # Sway configuration
    config = rec {
      modifier = "Mod4"; # Windows key
      terminal = "alacritty";
      menu = "bemenu-run";

      # Autostart applications
      startup = [
        { command = "swaymsg workspace ${workspace7}; exec nvim"; }
        { command = "swaymsg workspace ${workspace7}; exec alacritty"; }
        { command = "keepassxc"; }
        { command = "logseq"; }
        { command = "thunderbird"; }
        { command = "firefox"; }
        #{ command = "steam"; }
        # Update environment variables
        { command = "dbus-update-activation-environment --systemd DISPLAY WAYLAND_DISPLAY SWAYSOCK XDG_CURRENT_DESKTOP XDG_SESSION_TYPE NIXOS_OZONE_WL XCURSOR_THEME XCURSOR_SIZE PATH";}
        # Start sway-session.target
        { command = "systemctl --user start sway-session.target";}
        # Switch to the desired workspaces on each output
        #{ command = "swaymsg focus output ${display1}; swaymsg workspace ${workspace1}"; }
        #{ command = "swaymsg focus output ${display2}; swaymsg workspace ${workspace3}"; }
      ];

      # Keyboard layout
      input = {
        # Enable touch screen
        "10248:4117:FTS3528:00_2808:1015" = {
          #send_events = "enabled";
          #tap_enabled = "true";
          map_to_output = "${display1}";
        };

        # Map touch devices to display
        "type:touch" = {
          map_to_output = "${display1}";
        };

        # Configure Steam Controller pointer
        "10462:4613:Valve_Software_Steam_Controller" = {
          # For the pointer device
          #accel_speed = "0.0";
          natural_scroll = "false";
          left_handed = "false";
          scroll_method = "two_finger";
          middle_emulation = "true";
        };

        # Configure Steam Controller keyboard
        "10462:4613:Valve_Software_Steam_Controller" = {
          xkb_layout = "de";
        };

        # Set German layout for all keyboards
        "type:keyboard" = {
          xkb_layout = "de";
          repeat_delay = "600";
          repeat_rate = "25";
        };

        # For all pointers
        "type:pointer" = {
         # accel_speed = "0.0";
          natural_scroll = "false";
          left_handed = "false";
          middle_emulation = "true";
        };
        
        "*" = {
          xkb_layout = "de"; # German keyboard layout
        };
      };

      # Display configuration
      output = {
        "${display1}" = {
          res = "1280x800"; # Steam Deck resolution
          pos = "0 0";
          scale = "1";
        };
        "*" = {
          scale = "1";
        };
      };

      # Keybindings
      keybindings = {
        "Mod4+1" = "workspace ${workspace1}";
        "Mod4+2" = "workspace ${workspace2}";
        "Mod4+3" = "workspace ${workspace3}";
        "Mod4+4" = "workspace ${workspace4}";
        "Mod4+5" = "workspace ${workspace5}";
        "Mod4+6" = "workspace ${workspace6}";
        "Mod4+7" = "workspace ${workspace7}";
        "Mod4+8" = "workspace ${workspace8}";
        "Mod4+Shift+1" = "move container to workspace ${workspace1}";
        "Mod4+Shift+2" = "move container to workspace ${workspace2}";
        "Mod4+Shift+3" = "move container to workspace ${workspace3}";
        "Mod4+Shift+4" = "move container to workspace ${workspace4}";
        "Mod4+Shift+5" = "move container to workspace ${workspace5}";
        "Mod4+Shift+6" = "move container to workspace ${workspace6}";
        "Mod4+Shift+7" = "move container to workspace ${workspace7}";
        "Mod4+Shift+8" = "move container to workspace ${workspace8}";
        "Mod4+Mod1+f" = "exec firefox, workspace ${workspace1}";
        "Mod4+Mod1+g" = "exec logseq, workspace ${workspace2}";
        "Mod4+Mod1+t" = "exec thunderbird, workspace ${workspace3}";
        "Mod4+Mod1+s" = "exec signal-desktop, workspace ${workspace3}";
        "Mod4+Mod1+o" = "exec okular, workspace ${workspace4}";
        "Mod4+Mod1+c" = "exec codium, workspace ${workspace5}";
        "Mod4+Mod1+k" = "exec keepassxc, workspace ${workspace6}";
        "Mod4+Return" = "exec alacritty, workspace ${workspace7}";
        "Mod4+Mod1+p" = "exec alacritty -e pulsemixer, workspace ${workspace7}";
        "Mod4+Mod1+v" = "exec alacritty -e neovim, workspace ${workspace7}";
        "Mod4+Mod1+b" = "exec alacritty -e bluetuith, workspace ${workspace7}";
        "Mod4+Mod1+n" = "exec alacritty -e nmtui, workspace ${workspace7}";
        "Mod4+Mod1+h" = "exec alacritty -e htop, workspace ${workspace7}";
        "XF86AudioRaiseVolume" = "exec pactl set-sink-volume @DEFAULT_SINK@ +5%";
        "XF86AudioLowerVolume" = "exec pactl set-sink-volume @DEFAULT_SINK@ -5%";
        "XF86AudioMute" = "exec pactl set-sink-mute @DEFAULT_SINK@ toggle";
        "XF86AudioMicMute" = "exec pactl set-source-mute @DEFAULT_SOURCE@ toggle";
        "XF86MonBrightnessDown" = "exec brightnessctl set 5%-";
        "XF86MonBrightnessUp" = "exec brightnessctl set 5%+";
        "Print" = "exec grimshot save area";
        "Mod4+Shift+q" = "exec swaynagmode --exit";
        "Mod4+Shift+Return" = "exec swaynagmode --confirm";
        # steamdeck specific keys 
        # "bindcode 304" = "exec firefox";...
      };

      # Assign workspaces to outputs (adjust as needed)
      workspaceOutputAssign = [
        {
          workspace = workspace1;
          output = display1;
        }
        # Add other workspace-output assignments if you have multiple monitors
      ];

      # Assign applications to workspaces
      assigns = {
        "${workspace1}" = [ { app_id = "firefox"; } ];
        "${workspace2}" = [ { class = "Logseq"; } ];
        "${workspace3}" = [
          { class = "Signal"; }
          { app_id = "thunderbird"; }
        ];
        "${workspace4}" = [ { app_id = "org.kde.okular"; } ];
        "${workspace5}" = [
          { class = "VSCodium"; }
          { class = "nvim"; }
        ];
        "${workspace6}" = [ { app_id = "org.keepassxc.KeePassXC"; } ];
        "${workspace7}" = [ { app_id = "Alacritty"; } ];
        "${workspace8}" = [ 
          { class = "vlc"; } 
          { class = "steam"; }
        ];
      };
    };
  };

  services.swayidle = {
    enable = true;
    timeouts = [
      {
        timeout = 60 * 4;
        command = lib.getExe config.programs.swaylock.package;
      }
    ];
  };

  programs.swaylock = {
    enable = true;
    #package = pkgs.swaylock-effects;
    settings = {
      font = "hack";
      screenshots = true;
      clock = true;
      show-failed-attempts = true;
      indicator-idle-visible = true;
      effect-blur = "8x5";
    };
  };

}